@@ -1,8 +1,8 @@
 `chron` <-
     function(x, prefix="xxx", biweight=TRUE, prewhiten=FALSE)
 {
-    prefix <- as.character(prefix)
-    if(nchar(prefix) > 3)
+    prefix.str <- as.character(prefix)
+    if(length(prefix.str) != 1 || nchar(prefix.str) > 3)
         stop("'prefix' must be a character string with less than 4 characters")
     samps <- rowSums(!is.na(x))
     if(!biweight) std <- rowMeans(x, na.rm=TRUE)
@@ -13,12 +13,12 @@
         else res <- apply(x.ar, 1, tbrm, C=9)
         res[is.nan(res)] <- NA
         out <- data.frame(std, res, samps)
-        colnames(out) <- c(paste(prefix, "std", sep=""),
-                           paste(prefix, "res", sep=""),
+        colnames(out) <- c(paste(prefix.str, "std", sep=""),
+                           paste(prefix.str, "res", sep=""),
                            "samp.depth")
     } else{
         out <- data.frame(std, samps)
-        colnames(out) <- c(paste(prefix, "std", sep=""), "samp.depth")
+        colnames(out) <- c(paste(prefix.str, "std", sep=""), "samp.depth")
     }
     rownames(out) <- rownames(x)
     out
