@@ -1,6 +1,7 @@
 corr.rwl.seg <- function(rwl, seg.length=50, bin.floor=100, n=NULL,
                          prewhiten = TRUE, pcrit=0.05, biweight=TRUE,
-                         make.plot = TRUE, label.cex=1, ...){
+                         make.plot = TRUE, label.cex=1,
+                         floor.plus1 = FALSE, ...){
 
     ## helper function
     yr.range <- function(x, yr.vec=as.numeric(names(x))) {
@@ -26,10 +27,15 @@ corr.rwl.seg <- function(rwl, seg.length=50, bin.floor=100, n=NULL,
     nyrs <- length(yrs)
     min.yr <- min(yrs)
     max.yr <- max(yrs)
-    if(is.null(bin.floor) || bin.floor == 0) min.bin <- min.yr
-    else min.bin <- ceiling(min.yr/bin.floor) * bin.floor
-    bins <- seq(from=min.bin, to=max.yr-seg.length+1, by=seg.lag)
-    bins <- cbind(bins, bins+(seg.length-1))
+    if(is.null(bin.floor) || bin.floor == 0) {
+        min.bin <- min.yr
+    } else if(floor.plus1) {
+        min.bin <- ceiling((min.yr - 1) / bin.floor) * bin.floor + 1
+    } else {
+        min.bin <- ceiling(min.yr / bin.floor) * bin.floor
+    }
+    bins <- seq(from=min.bin, to=max.yr - seg.length + 1, by=seg.lag)
+    bins <- cbind(bins, bins + (seg.length - 1))
     nbins <- nrow(bins)
     bin.names <- paste(bins[, 1], ".", bins[, 2], sep="")
     ## structures for results
@@ -52,7 +58,7 @@ corr.rwl.seg <- function(rwl, seg.length=50, bin.floor=100, n=NULL,
     idx.good <- norm.one$idx.good
 
     ## loop through series
-    for(i in 1:nseries){
+    for(i in seq_len(nseries)){
         idx.noti <- rep(TRUE, nseries)
         idx.noti[i] <- FALSE
         master.norm <- rwi[, idx.good & idx.noti, drop=FALSE]
@@ -60,17 +66,17 @@ corr.rwl.seg <- function(rwl, seg.length=50, bin.floor=100, n=NULL,
         ## compute master series by normal mean or robust mean
         master <- vector(mode="numeric", length=nyrs)
         if (!biweight){
-            for (j in 1:nyrs)
+            for (j in seq_len(nyrs))
                 master[j] <- exactmean(master.norm[j, ])
         } else {
             ## surprisingly, for loop is faster than apply
-            for (j in 1:nyrs)
+            for (j in seq_len(nyrs))
                 master[j] <- tbrm(master.norm[j, ], C=9)
         }
         series <- rwi[, i]
         ## loop through bins
-        for(j in 1:nbins){
-            mask <- yrs%in%seq(from=bins[j, 1], to=bins[j, 2])
+        for(j in seq_len(nbins)){
+            mask <- yrs %in% seq(from=bins[j, 1], to=bins[j, 2])
             ## cor is NA if there is not complete overlap
             if(!any(mask) ||
                any(is.na(series[mask])) ||
@@ -101,7 +107,7 @@ corr.rwl.seg <- function(rwl, seg.length=50, bin.floor=100, n=NULL,
     names(seg.flags) <- cnames
     flag.logical <- res.pval >= pcrit
     flag.logical[is.na(flag.logical)] <- FALSE
-    for(i in 1:length(seg.flags))
+    for(i in seq_along(seg.flags))
         seg.flags[i] <- paste(names(flag.logical[i, flag.logical[i, ]]),
                               collapse = ", ")
     seg.flags <- seg.flags[seg.flags != ""]
@@ -111,13 +117,11 @@ corr.rwl.seg <- function(rwl, seg.length=50, bin.floor=100, n=NULL,
         p.val <- res.pval
         segs <- rwi
         extreme.year <- apply(segs, 2, yr.range, yr.vec=yrs)
-        first.year <- extreme.year[1, ]
-        rsult <- sort.int(first.year, decreasing=FALSE, index.return=TRUE)
+        rsult <- sort.int(extreme.year[1, ], decreasing=FALSE,
+                          index.return=TRUE)
         neworder <- rsult$ix
         segs <- segs[, neworder, drop=FALSE]
         segs.mat <- t(extreme.year[, neworder])
-        first.year <- first.year[neworder]
-        last.year <- extreme.year[2, neworder]
 
         nsegs <- ncol(segs)
         op <- par(no.readonly=TRUE)
@@ -130,65 +134,49 @@ corr.rwl.seg <- function(rwl, seg.length=50, bin.floor=100, n=NULL,
              domain="R-dplR"),
              ...)
         ## bounding poly for even series
-        xx <- c(min.yr-100, max.yr+100)
+        xx <- c(min.yr - 100, max.yr + 100)
         xx <- c(xx, rev(xx))
         for(i in seq(from=1, to=nseries, by=2)){
-            yy <- c(i-0.5, i-0.5, i+0.5, i+0.5)
+            yy <- c(i - 0.5, i - 0.5, i + 0.5, i + 0.5)
             polygon(xx, yy, col="grey90", border=NA)
         }
-        abline(v=bins, col="grey", lty="dotted")
+        abline(v=c(bins[, 1], bins[c(nbins - 1, nbins), 2] + 1),
+               col="grey", lty="dotted")
 
         ## First odd segs, then even segs
         y.offset <- c(-0.25, 0.25)
         ax <- c(1, 3)
-        for(odd.even in 1:2){
+        for(odd.even in c(1, 2)){
             this.seq <- seq(from=odd.even, to=nbins, by=2)
             these.bins <- bins[this.seq, , drop=FALSE]
-            com.segs <- matrix(1, ncol=nseries, nrow=nyrs)
+            com.segs <- matrix(NA, ncol=nseries, nrow=nyrs)
             flag.segs <- matrix(NA, ncol=nseries, nrow=nyrs)
             ## loop through these.bins
             tmp <- p.val[neworder, this.seq, drop=FALSE] > pcrit
-            for(i in 1:nseries){
-                for(j in 1:nrow(these.bins)){
-                    ## minus 1 deals with edge in segment graphing
+            for(i in seq_len(nseries)){
+                for(j in seq_len(nrow(these.bins))){
                     mask <- yrs%in%seq(from = these.bins[j, 1],
-                                       to = these.bins[j, 2]-1)
-                    ## note lack of complete overlap
-                    if(any(is.na(segs[mask, i])))
-                        com.segs[mask, i] <- NA
-                    if(is.na(tmp[i, j]))
-                        com.segs[mask, i] <- NA
-                    else if(tmp[i, j]){
-                        mask2 <- yrs%in%seq(from = these.bins[j, 1],
-                                            to = these.bins[j, 2])
-                        flag.segs[mask2, i] <- 1
+                                       to = these.bins[j, 2])
+                    if(!is.na(tmp[i, j])) {
+                        com.segs[mask, i] <- 1
+                        if(tmp[i, j]) {
+                            flag.segs[mask, i] <- 1
+                        }
                     }
                 }
-                ## make sure any segment past year range is NA for
-                ## com.segs this is a fix because there was an errant
-                ## 1 in floating series that was not getting tagged
-                ## because of the mask indexing: these.bins[j, 2]-1
-                ## that deals with the bin overlap issue. This should
-                ## fix it.
-                mask3 <- yrs%in%seq(first.year[i], last.year[i])
-                com.segs[!mask3, i] <- NA
             }
-            idx.small.large <-
-                yrs < min(these.bins) | yrs > max(these.bins)
-            com.segs[idx.small.large, ] <- NA
-            flag.segs[idx.small.large, ] <- NA
 
             com.segs.mat <-
                 t(apply(com.segs, 2, yr.range, yr.vec=yrs))
-            flag.segs.mat <-
-                t(apply(flag.segs, 2, yr.range, yr.vec=yrs))
 
-            axis(ax[odd.even], at=these.bins)
             ## polygons for these bins (go down or up from series line)
             y.deviation <- y.offset[odd.even]
-            guides.x.base <- c(these.bins, recursive=T)
-            guides.x.base <- sort(guides.x.base[!duplicated(guides.x.base)])
-            for(i in seq(from=1, to=nseries)){
+            guides.x.base <-
+                c(these.bins[, 1], these.bins[length(this.seq), 2] + 1)
+            ## Ticks at 1) first year of each bin,
+            ## and 2) first year larger than any of these bins
+            axis(ax[odd.even], at=guides.x.base)
+            for(i in seq_len(nseries)){
                 y.deviation <- y.deviation + 1
                 ## whole segs
                 xx <- segs.mat[i, ]
@@ -200,9 +188,12 @@ corr.rwl.seg <- function(rwl, seg.length=50, bin.floor=100, n=NULL,
                 xx <- c(xx, rev(xx))
                 polygon(xx, yy, col=col.pal[2], border=NA)
                 ## flags
-                xx <- flag.segs.mat[i, ]
-                xx <- c(xx, rev(xx))
-                polygon(xx, yy, col=col.pal[1], border=NA)
+                flag.segs.mat <- yr.ranges(flag.segs[, i], yrs)
+                for(j in seq_len(nrow(flag.segs.mat))) {
+                    xx <- flag.segs.mat[j, ]
+                    xx <- c(xx, rev(xx))
+                    polygon(xx, yy, col=col.pal[1], border=NA)
+                }
                 ## guides
                 guides.x <- guides.x.base[guides.x.base >= segs.mat[i, 1]]
                 guides.x <- guides.x[guides.x <= segs.mat[i, 2]]
@@ -220,7 +211,7 @@ corr.rwl.seg <- function(rwl, seg.length=50, bin.floor=100, n=NULL,
         axis(4, at=even.seq,
              labels=cnames.segs[even.seq], srt=45,
              tick=FALSE, las=2, cex.axis=label.cex)
-        abline(h=1:nseries, col="white")
+        abline(h=seq_len(nseries), col="white")
         box()
     }
 
